@@ -27,7 +27,7 @@
 #include <KConfigGroup>
 #include <KNumInput>
 #include <KRandom>
-
+#include <KLocalizedString>
 //BEGIN Kolf::BlackHole
 
 Kolf::BlackHole::BlackHole(QGraphicsItem* parent, b2World* world)
@@ -355,4 +355,4 @@ bool Kolf::Cup::collision(Ball* ball)
 
 //END Kolf::Cup
 
-#include "objects.moc"
+
